MacroRankBasedEvaluator
=======================

.. currentmodule:: pykeen.evaluation

.. autoclass:: MacroRankBasedEvaluator
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MacroRankBasedEvaluator.COLUMNS

   .. rubric:: Methods Summary

   .. autosummary::

      ~MacroRankBasedEvaluator.finalize
      ~MacroRankBasedEvaluator.process_scores_

   .. rubric:: Attributes Documentation

   .. autoattribute:: COLUMNS

   .. rubric:: Methods Documentation

   .. automethod:: finalize
   .. automethod:: process_scores_
